Learn R Programming

lrequire (version 0.1.3)

show.not.found.warnings: Globally show warnings when modules are not found

Description

This is the default behaviour.

Usage

show.not.found.warnings()

Arguments

Value

nothing is returned

Details

This is only to be called when handling results manually. This will be overridden by a warn.not.found parameter explicitly set by either lrequire or find.first.R.

Examples

Run this code
# Ensure warnings are displayed when lrequire cannot find the module
show.not.found.warnings()

Run the code above in your browser using DataLab